module.exports={A:{A:{"2":"K D E vC","520":"F A B"},B:{"1":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I","8":"C L","388":"M G N O P"},C:{"1":"0 1 2 3 4 5 EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC","2":"wC SC zC 0C","132":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB"},D:{"1":"0 1 2 3 4 5 BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC","2":"J XB","132":"6 7 8 9 K D E F A B C L M G N O P YB AB"},E:{"2":"1C","8":"J XB YC 2C","520":"K D E F A B C 3C 4C 5C ZC MC","16385":"PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","17412":"L NC 6C","23556":"M","24580":"G 7C 8C aC bC OC 9C"},F:{"1":"0 1 2 3 4 5 6 7 8 9 N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F DD ED FD","132":"B C G GD MC tC HD NC"},G:{"2":"E YC ID uC JD KD LD MD ND OD PD QD RD SD TD","16385":"kC lC eD RC mC nC oC pC qC rC sC","17412":"UD VD WD XD YD","19460":"ZD aD bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC"},H:{"2":"fD"},I:{"1":"I","2":"gD hD","132":"SC J iD jD uC kD lD"},J:{"2":"D A"},K:{"1":"H","2":"A B C MC tC NC"},L:{"1":"I"},M:{"1":"LC"},N:{"8":"A B"},O:{"1":"OC"},P:{"1":"6 7 8 9 AB BB CB DB EB mD nD oD pD qD ZC rD sD tD uD vD PC QC RC wD","132":"J"},Q:{"1":"xD"},R:{"1":"yD"},S:{"1":"zD 0D"}},B:6,C:"WebM video format",D:true};
