module.exports={A:{A:{"2":"K D E F vC","129":"A B"},B:{"1":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I","129":"C L","1025":"M G N O P"},C:{"2":"6 7 8 9 wC SC J XB K D E F A B C L M G N O P YB AB BB CB DB EB zC 0C","513":"0 1 2 3 4 5 ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC","2":"J XB"},E:{"1":"XB K D E F A B C L M G 2C 3C 4C 5C ZC MC NC 6C 7C 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","2":"J 1C YC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 F B C G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z DD ED FD GD MC tC HD NC"},G:{"388":"E YC ID uC JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC"},H:{"2":"fD"},I:{"2":"SC gD hD iD","388":"J I jD uC kD lD"},J:{"2":"D","388":"A"},K:{"1":"A B C MC tC NC","388":"H"},L:{"388":"I"},M:{"641":"LC"},N:{"388":"A B"},O:{"388":"OC"},P:{"388":"6 7 8 9 J AB BB CB DB EB mD nD oD pD qD ZC rD sD tD uD vD PC QC RC wD"},Q:{"388":"xD"},R:{"388":"yD"},S:{"513":"zD 0D"}},B:1,C:"Number input type",D:true};
