module.exports={A:{A:{"1":"B","2":"K D E F A vC"},B:{"1":"0 1 2 3 4 5 M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I","129":"C L"},C:{"1":"0 1 2 3 4 5 uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC","2":"wC SC","260":"6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB","804":"J XB K D E F A B C L M zC 0C"},D:{"1":"0 1 2 3 4 5 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC","260":"vB wB xB yB zB","388":"aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB","1412":"6 7 8 9 G N O P YB AB BB CB DB EB ZB","1956":"J XB K D E F A B C L M"},E:{"1":"bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","129":"A B C L M G 5C ZC MC NC 6C 7C 8C aC","1412":"K D E F 3C 4C","1956":"J XB 1C YC 2C"},F:{"1":"0 1 2 3 4 5 nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F DD ED","260":"iB jB kB lB mB","388":"6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB","1796":"FD GD","1828":"B C MC tC HD NC"},G:{"1":"bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC","129":"OD PD QD RD SD TD UD VD WD XD YD ZD aD bD aC","1412":"E KD LD MD ND","1956":"YC ID uC JD"},H:{"1828":"fD"},I:{"1":"I","388":"kD lD","1956":"SC J gD hD iD jD uC"},J:{"1412":"A","1924":"D"},K:{"1":"H","2":"A","1828":"B C MC tC NC"},L:{"1":"I"},M:{"1":"LC"},N:{"1":"B","2":"A"},O:{"1":"OC"},P:{"1":"6 7 8 9 AB BB CB DB EB oD pD qD ZC rD sD tD uD vD PC QC RC wD","260":"mD nD","388":"J"},Q:{"1":"xD"},R:{"1":"yD"},S:{"1":"0D","260":"zD"}},B:4,C:"CSS3 Border images",D:true};
