module.exports={A:{A:{"2436":"K D E F A B vC"},B:{"260":"O P","2436":"C L M G N","8196":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I"},C:{"2":"6 7 wC SC J XB K D E F A B C L M G N O P YB zC 0C","772":"8 9 AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB","4100":"0 1 2 3 4 5 lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC"},D:{"2":"J XB K D E F A B C","2564":"6 7 8 9 L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB","8196":"0 1 2 3 4 5 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC","10244":"nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B"},E:{"1":"C L M G NC 6C 7C 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","16":"1C YC","2308":"A B ZC MC","2820":"J XB K D E F 2C 3C 4C 5C"},F:{"2":"F B DD ED FD GD MC tC HD","16":"C","516":"NC","2564":"6 7 8 9 G N O P YB AB BB CB DB EB ZB","8196":"0 1 2 3 4 5 pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","10244":"aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB"},G:{"1":"TD UD VD WD XD YD ZD aD bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC","2":"YC ID uC","2820":"E JD KD LD MD ND OD PD QD RD SD"},H:{"2":"fD"},I:{"2":"SC J gD hD iD jD uC","260":"I","2308":"kD lD"},J:{"2":"D","2308":"A"},K:{"2":"A B C MC tC","16":"NC","8196":"H"},L:{"8196":"I"},M:{"1028":"LC"},N:{"2":"A B"},O:{"8196":"OC"},P:{"2052":"mD nD","2308":"J","8196":"6 7 8 9 AB BB CB DB EB oD pD qD ZC rD sD tD uD vD PC QC RC wD"},Q:{"8196":"xD"},R:{"8196":"yD"},S:{"4100":"zD 0D"}},B:5,C:"Synchronous Clipboard API",D:true};
