module.exports={A:{A:{"2":"K vC","2340":"D E F A B"},B:{"2":"C L M G N O P","1025":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I"},C:{"1":"0 1 2 3 4 5 c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC","2":"wC SC zC","513":"7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b","545":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 0C"},D:{"2":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB","1025":"0 1 2 3 4 5 lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC"},E:{"1":"A B C L M G ZC MC NC 6C 7C 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","2":"J XB 1C YC 2C","164":"K","4644":"D E F 3C 4C 5C"},F:{"2":"6 7 8 9 F B G N O P YB AB BB CB DB DD ED FD GD MC tC","545":"C HD NC","1025":"0 1 2 3 4 5 EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"1":"PD QD RD SD TD UD VD WD XD YD ZD aD bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC","2":"YC ID uC","4260":"JD KD","4644":"E LD MD ND OD"},H:{"2":"fD"},I:{"2":"SC J gD hD iD jD uC kD lD","1025":"I"},J:{"2":"D","4260":"A"},K:{"2":"A B MC tC","545":"C NC","1025":"H"},L:{"1025":"I"},M:{"1":"LC"},N:{"2340":"A B"},O:{"1025":"OC"},P:{"1025":"6 7 8 9 J AB BB CB DB EB mD nD oD pD qD ZC rD sD tD uD vD PC QC RC wD"},Q:{"1025":"xD"},R:{"1025":"yD"},S:{"1":"0D","4097":"zD"}},B:4,C:"Crisp edges/pixelated images",D:true};
