module.exports={A:{A:{"2":"F A B vC","8":"K D E"},B:{"1":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I","2":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC","2":"wC","8":"6 7 8 9 SC J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB zC 0C","194":"rB sB"},D:{"1":"0 1 2 3 4 5 gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC","8":"J XB K D E F A B","257":"6 7 8 9 YB AB BB CB DB EB ZB aB bB cB dB eB fB","769":"C L M G N O P"},E:{"1":"C L M G NC 6C 7C 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","8":"J XB 1C YC 2C","257":"K D E F A 3C 4C 5C","1025":"B ZC MC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"C MC tC HD NC","8":"F B DD ED FD GD"},G:{"1":"E KD LD MD ND OD SD TD UD VD WD XD YD ZD aD bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC","8":"YC ID uC JD","1025":"PD QD RD"},H:{"8":"fD"},I:{"1":"J I jD uC kD lD","8":"SC gD hD iD"},J:{"1":"A","8":"D"},K:{"1":"H","8":"A B C MC tC NC"},L:{"1":"I"},M:{"1":"LC"},N:{"2":"A B"},O:{"1":"OC"},P:{"1":"6 7 8 9 J AB BB CB DB EB mD nD oD pD qD ZC rD sD tD uD vD PC QC RC wD"},Q:{"1":"xD"},R:{"1":"yD"},S:{"1":"zD 0D"}},B:1,C:"Details & Summary elements",D:true};
