module.exports={A:{A:{"2":"K D E vC","132":"F A B"},B:{"1":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I","1028":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC","2":"wC SC","260":"J XB K D E F A B C L M G zC 0C","1028":"6 7 8 9 N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC"},D:{"1":"0 1 2 3 4 5 AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC","548":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB","1028":"ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B"},E:{"1":"PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","2":"1C YC","548":"J XB K D E F A B C L M G 2C 3C 4C 5C ZC MC NC 6C 7C 8C aC bC OC 9C"},F:{"1":"0 1 2 3 4 5 zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z NC","2":"F","548":"B C DD ED FD GD MC tC HD","1028":"6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB"},G:{"1":"PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC","16":"YC","548":"E ID uC JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD aC bC OC cD"},H:{"132":"fD"},I:{"1":"I","16":"gD hD","548":"SC J iD jD uC","1028":"kD lD"},J:{"548":"D A"},K:{"1":"H NC","548":"A B C MC tC"},L:{"1":"I"},M:{"1":"LC"},N:{"132":"A B"},O:{"1":"OC"},P:{"1":"6 7 8 9 AB BB CB DB EB ZC rD sD tD uD vD PC QC RC wD","1028":"J mD nD oD pD qD"},Q:{"1":"xD"},R:{"1":"yD"},S:{"1":"zD 0D"}},B:4,C:"Media Queries: resolution feature",D:true};
