module.exports={A:{A:{"2":"K D E vC","2561":"A B","2692":"F"},B:{"1":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I","2561":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC","16":"wC","1537":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB 0C","1796":"SC zC"},D:{"1":"0 1 2 3 4 5 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC","16":"J XB K D E F A B C L M","1025":"fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B","1537":"6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB cB dB eB"},E:{"1":"M G 6C 7C 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","16":"J XB K 1C YC","1025":"D E F A B C 3C 4C 5C ZC MC","1537":"2C","4097":"L NC"},F:{"1":"0 1 2 3 4 5 wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z NC","16":"F B C DD ED FD GD MC tC","260":"HD","1025":"8 9 AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB","1537":"6 7 G N O P YB"},G:{"1":"WD XD YD ZD aD bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC","16":"YC ID uC","1025":"E MD ND OD PD QD RD SD TD","1537":"JD KD LD","4097":"UD VD"},H:{"2":"fD"},I:{"16":"gD hD","1025":"I lD","1537":"SC J iD jD uC kD"},J:{"1025":"A","1537":"D"},K:{"1":"A B C H MC tC NC"},L:{"1":"I"},M:{"1":"LC"},N:{"2561":"A B"},O:{"1":"OC"},P:{"1025":"6 7 8 9 J AB BB CB DB EB mD nD oD pD qD ZC rD sD tD uD vD PC QC RC wD"},Q:{"1":"xD"},R:{"1":"yD"},S:{"1":"0D","1537":"zD"}},B:1,C:"input event",D:true};
