module.exports={A:{A:{"388":"A B","900":"K D E F vC"},B:{"388":"C L M G N O P","641":"0 1 2 3 4 5 r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I","900":"Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q"},C:{"772":"0 1 2 3 4 5 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC","900":"6 7 8 9 wC SC J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B zC 0C"},D:{"641":"0 1 2 3 4 5 r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC","900":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q"},E:{"772":"A","900":"J XB K D E F B C L M G 1C YC 2C 3C 4C 5C ZC MC NC 6C 7C 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD"},F:{"16":"F DD","129":"B C ED FD GD MC tC HD NC","641":"0 1 2 3 4 5 d e f g h i j k l m n o p q r s t u v w x y z","900":"6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c"},G:{"900":"E YC ID uC JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC"},H:{"129":"fD"},I:{"641":"I","900":"SC J gD hD iD jD uC kD lD"},J:{"900":"D A"},K:{"129":"A B C MC tC NC","641":"H"},L:{"900":"I"},M:{"772":"LC"},N:{"388":"A B"},O:{"900":"OC"},P:{"641":"7 8 9 AB BB CB DB EB","900":"6 J mD nD oD pD qD ZC rD sD tD uD vD PC QC RC wD"},Q:{"900":"xD"},R:{"900":"yD"},S:{"772":"0D","900":"zD"}},B:2,C:"CSS page-break properties",D:true};
