module.exports={A:{A:{"2":"K D E F A B vC"},B:{"1":"0 1 2 3 4 5 Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I","2":"C L M G N O P","1028":"W X","1540":"Q H R S T U V"},C:{"1":"0 1 2 3 4 5 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC","2":"wC","164":"6 7 8 9 SC J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB zC 0C","1540":"lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B"},D:{"1":"0 1 2 3 4 5 Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC","292":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC","1028":"W X","1540":"BC CC DC EC FC GC HC IC JC KC Q H R S T U V"},E:{"1":"G 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","292":"J XB K D E F A B C 1C YC 2C 3C 4C 5C ZC MC","1540":"L M NC 6C","3076":"7C"},F:{"1":"0 1 2 3 4 5 IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F B C DD ED FD GD MC tC HD NC","292":"6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB","1028":"GC HC","1540":"0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC"},G:{"1":"bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC","292":"E YC ID uC JD KD LD MD ND OD PD QD RD SD TD","1540":"UD VD WD XD YD ZD","3076":"aD"},H:{"2":"fD"},I:{"1":"I","292":"SC J gD hD iD jD uC kD lD"},J:{"292":"D A"},K:{"1":"H","2":"A B C MC tC NC"},L:{"1":"I"},M:{"1":"LC"},N:{"2":"A B"},O:{"1":"OC"},P:{"1":"6 7 8 9 AB BB CB DB EB vD PC QC RC wD","292":"J mD nD oD pD qD","1540":"ZC rD sD tD uD"},Q:{"1540":"xD"},R:{"1":"yD"},S:{"1":"0D","1540":"zD"}},B:5,C:"CSS Logical Properties",D:true};
