module.exports={A:{A:{"1":"A B","2":"K D E F vC"},B:{"1":"C L M G N O P","516":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I"},C:{"132":"wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B","164":"6 7 8 9 wC SC J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB zC 0C","516":"7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a","1028":"0 1 2 3 4 5 b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC"},D:{"420":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB","516":"0 1 2 3 4 5 uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC"},E:{"1":"A B C L M G ZC MC NC 6C 7C 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","132":"F 5C","164":"D E 4C","420":"J XB K 1C YC 2C 3C"},F:{"1":"C MC tC HD NC","2":"F B DD ED FD GD","420":"6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB","516":"0 1 2 3 4 5 hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"1":"PD QD RD SD TD UD VD WD XD YD ZD aD bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC","132":"ND OD","164":"E LD MD","420":"YC ID uC JD KD"},H:{"1":"fD"},I:{"420":"SC J gD hD iD jD uC kD lD","516":"I"},J:{"420":"D A"},K:{"1":"C MC tC NC","2":"A B","516":"H"},L:{"516":"I"},M:{"1028":"LC"},N:{"1":"A B"},O:{"516":"OC"},P:{"420":"J","516":"6 7 8 9 AB BB CB DB EB mD nD oD pD qD ZC rD sD tD uD vD PC QC RC wD"},Q:{"516":"xD"},R:{"516":"yD"},S:{"164":"zD 0D"}},B:4,C:"CSS3 Multiple column layout",D:true};
