module.exports={A:{A:{"1":"B","4":"K D E F A vC"},B:{"1":"C L M G N","129":"0 1 2 3 4 5 O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I"},C:{"1":"6 7 8 9 K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB","4":"wC SC J XB zC 0C","129":"0 1 2 3 4 5 vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC"},D:{"1":"pB qB rB sB tB uB vB wB xB yB","4":"J XB K","129":"0 1 2 3 4 5 6 7 8 9 D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC"},E:{"4":"J XB 1C YC","129":"K D E F A B C L M G 2C 3C 4C 5C ZC MC NC 6C 7C 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD"},F:{"1":"C cB dB eB fB gB hB iB jB kB lB MC tC HD NC","4":"F B DD ED FD GD","129":"0 1 2 3 4 5 6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"4":"YC ID uC","129":"E JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC"},H:{"4":"fD"},I:{"4":"gD hD iD","129":"SC J I jD uC kD lD"},J:{"129":"D A"},K:{"1":"C MC tC NC","4":"A B","129":"H"},L:{"129":"I"},M:{"129":"LC"},N:{"1":"B","4":"A"},O:{"129":"OC"},P:{"129":"6 7 8 9 J AB BB CB DB EB mD nD oD pD qD ZC rD sD tD uD vD PC QC RC wD"},Q:{"129":"xD"},R:{"129":"yD"},S:{"1":"zD","129":"0D"}},B:1,C:"dataset & data-* attributes",D:true};
