module.exports={A:{A:{"1":"A B","2":"F vC","8":"K D E"},B:{"1":"C L M G N O P Q H R S T","2":"0 1 2 3 4 5 U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I"},C:{"1":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S zC 0C","2":"0 1 2 3 4 5 T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC","4":"SC","8":"wC"},D:{"1":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T","2":"0 1 2 3 4 5 U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC"},E:{"1":"J XB K D E F A B C L M 2C 3C 4C 5C ZC MC NC 6C 7C","2":"G 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","8":"1C YC"},F:{"1":"6 7 8 9 B C G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC GD MC tC HD NC","2":"0 1 2 3 4 5 F FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z DD","8":"ED FD"},G:{"1":"E YC ID uC JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD","2":"bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC"},H:{"2":"fD"},I:{"1":"SC J gD hD iD jD uC kD lD","2":"I"},J:{"1":"D A"},K:{"1":"B C MC tC NC","2":"A H"},L:{"2":"I"},M:{"2":"LC"},N:{"1":"A B"},O:{"1":"OC"},P:{"1":"6 7 8 9 J AB BB CB DB EB mD nD oD pD qD ZC rD sD tD uD vD PC QC RC wD"},Q:{"1":"xD"},R:{"2":"yD"},S:{"1":"zD","2":"0D"}},B:7,C:"Offline web applications",D:true};
