module.exports={A:{A:{"2":"K D E F A B vC"},B:{"2":"C L M G N O P","1025":"0 1 2 3 4 5 d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I","1537":"Q H R S T U V W X Y Z a b c"},C:{"2":"wC","932":"6 7 8 9 SC J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B zC 0C","2308":"0 1 2 3 4 5 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC"},D:{"2":"6 7 J XB K D E F A B C L M G N O P YB","545":"8 9 AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB","1025":"0 1 2 3 4 5 d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC","1537":"qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c"},E:{"1":"PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","2":"J XB K 1C YC 2C","516":"B C L M G MC NC 6C 7C 8C aC bC OC 9C","548":"F A 5C ZC","676":"D E 3C 4C"},F:{"2":"F B C DD ED FD GD MC tC HD NC","513":"eB","545":"6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB cB","1025":"0 1 2 3 4 5 e f g h i j k l m n o p q r s t u v w x y z","1537":"dB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d"},G:{"1":"PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC","2":"YC ID uC JD KD","516":"ZD aD bD aC bC OC cD","548":"ND OD PD QD RD SD TD UD VD WD XD YD","676":"E LD MD"},H:{"2":"fD"},I:{"2":"SC J gD hD iD jD uC","545":"kD lD","1025":"I"},J:{"2":"D","545":"A"},K:{"2":"A B C MC tC NC","1025":"H"},L:{"1025":"I"},M:{"2308":"LC"},N:{"2":"A B"},O:{"1537":"OC"},P:{"545":"J","1025":"6 7 8 9 AB BB CB DB EB QC RC wD","1537":"mD nD oD pD qD ZC rD sD tD uD vD PC"},Q:{"1537":"xD"},R:{"1537":"yD"},S:{"932":"zD","2308":"0D"}},B:5,C:"Intrinsic & Extrinsic Sizing",D:true};
