module.exports={A:{A:{"2":"K D E F A B vC"},B:{"2":"C L M G N O P Q","1537":"0 1 2 3 4 5 H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I"},C:{"2":"wC SC zC 0C","260":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB","513":"0 1 2 3 4 5 lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC"},D:{"2":"6 7 8 9 J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q","1537":"0 1 2 3 4 5 H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC"},E:{"1":"rC sC CD","2":"J XB K D E F A B C L M G 1C YC 2C 3C 4C 5C ZC MC NC 6C 7C 8C aC bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC"},F:{"1":"oB pB qB rB sB tB uB vB wB xB","2":"6 7 8 9 F B C G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B DD ED FD GD MC tC HD NC","1537":"0 1 2 3 4 5 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"1":"rC sC","2":"TD UD VD WD XD YD ZD aD bD aC bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC","130":"E YC ID uC JD KD LD MD ND OD PD QD RD SD"},H:{"130":"fD"},I:{"2":"SC J I gD hD iD jD uC kD lD"},J:{"2":"D","130":"A"},K:{"130":"A B C MC tC NC","1537":"H"},L:{"1537":"I"},M:{"2":"LC"},N:{"130":"A B"},O:{"2":"OC"},P:{"2":"J mD nD oD pD qD ZC rD sD","1537":"6 7 8 9 AB BB CB DB EB tD uD vD PC QC RC wD"},Q:{"2":"xD"},R:{"1537":"yD"},S:{"513":"zD 0D"}},B:1,C:"SVG favicons",D:true};
