module.exports={A:{A:{"2":"K D E F A B vC"},B:{"2":"C L M G N O P","33":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I"},C:{"1":"0 1 2 3 4 5 sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC xC yC","2":"6 7 8 9 wC SC J XB K D E F A B C L M G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB zC 0C"},D:{"16":"J XB K D E F A B C L M G N O P","33":"0 1 2 3 4 5 6 7 8 9 YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B TC 3B UC 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB I WC LC XC"},E:{"1":"bC OC 9C PC cC dC eC fC gC AD QC hC iC jC kC lC BD RC mC nC oC pC qC rC sC CD","2":"J XB 1C YC 2C","33":"K D E F A B C L M G 3C 4C 5C ZC MC NC 6C 7C 8C aC"},F:{"2":"F B C DD ED FD GD MC tC HD NC","33":"0 1 2 3 4 5 6 7 8 9 G N O P YB AB BB CB DB EB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC Q H R VC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"1":"bC OC cD PC cC dC eC fC gC dD QC hC iC jC kC lC eD RC mC nC oC pC qC rC sC","16":"E YC ID uC JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD aC"},H:{"2":"fD"},I:{"16":"SC J gD hD iD jD uC kD lD","33":"I"},J:{"16":"D A"},K:{"2":"A B C MC tC NC","33":"H"},L:{"16":"I"},M:{"1":"LC"},N:{"16":"A B"},O:{"16":"OC"},P:{"16":"6 7 8 9 J AB BB CB DB EB mD nD oD pD qD ZC rD sD tD uD vD PC QC RC wD"},Q:{"33":"xD"},R:{"16":"yD"},S:{"1":"zD 0D"}},B:4,C:"CSS print-color-adjust",D:true};
